@@ -19,7 +19,7 @@
 //! let builder = new_manifest("Company.OrgUnit.Program");
 //! assert_eq!(format!("{:#}", builder), r#"<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 //! <assembly xmlns="urn:schemas-microsoft-com:asm.v1" xmlns:asmv3="urn:schemas-microsoft-com:asm.v3" manifestVersion="1.0">
-//!     <assemblyIdentity name="Company.OrgUnit.Program" type="win32" version="1.4.0.0"/>
+//!     <assemblyIdentity name="Company.OrgUnit.Program" type="win32" version="1.5.0.0"/>
 //!     <dependency>
 //!         <dependentAssembly>
 //!             <assemblyIdentity language="*" name="Microsoft.Windows.Common-Controls" processorArchitecture="*" publicKeyToken="6595b64144ccf1df" type="win32" version="6.0.0.0"/>
@@ -311,13 +311,8 @@ impl Display for ManifestBuilder {
         if let Some(ref identity) = self.identity {
             identity.xml_to(&mut w)?;
         }
-        if !self.dependent_assemblies.is_empty() {
-            w.element("dependency", &[], |w| {
-                for d in self.dependent_assemblies.as_slice() {
-                    w.element("dependentAssembly", &[], |w| d.xml_to(w))?;
-                }
-                Ok(())
-            })?;
+        for d in self.dependent_assemblies.as_slice() {
+            w.element("dependency", &[], |w| w.element("dependentAssembly", &[], |w| d.xml_to(w)))?;
         }
         if !self.compatibility.is_empty() {
             self.compatibility.xml_to(&mut w)?;
